# FeatureFlag

Controls whether a feature is enabled.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**feature** | **str** | The name of the feature | 
**enabled** | **bool** | Whether the feature is enabled | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


